Author: jamessan
Date: Sun Mar 27 20:29:22 2022
New Revision: 1899264

URL: http://svn.apache.org/viewvc?rev=1899264&view=rev
Log:
* tools/dist/backport.pl: Continue chasing the experimental nature of 'given'
    and 'when', through perl5340delta.

Modified:
    subversion/trunk/tools/dist/backport.pl

Modified: subversion/trunk/tools/dist/backport.pl
URL: 
http://svn.apache.org/viewvc/subversion/trunk/tools/dist/backport.pl?rev=1899264&r1=1899263&r2=1899264&view=diff
==============================================================================
--- subversion/trunk/tools/dist/backport.pl (original)
+++ subversion/trunk/tools/dist/backport.pl Sun Mar 27 20:29:22 2022
@@ -9,11 +9,11 @@ use v5.10.0; # needed for $^V
 # experimental and "subject to change" in v5.18 (see perl5180delta).  Every
 # use of it now triggers a warning.
 #
 # As of Perl v5.30.0, the semantics of given/when provided by Perl are
 # compatible with those expected by the script, so disable the warning for
 # those Perls.  But don't try to disable the the warning category on Perls
 # that don't know that category, since that breaks compilation.
-no if (v5.17.0 le $^V and $^V le v5.30.0),
+no if (v5.17.0 le $^V and $^V le v5.34.0),
    warnings => 'experimental::smartmatch';
 
 # Licensed to the Apache Software Foundation (ASF) under one
@@ -9,11 +9,11 @@ use v5.10.0; # needed for $^V
 # use of it now triggers a warning.
 #
-# As of Perl v5.30.0, the semantics of given/when provided by Perl are
+# As of Perl v5.34.0, the semantics of given/when provided by Perl are
 # compatible with those expected by the script, so disable the warning for
 # those Perls.  But don't try to disable the the warning category on Perls


Reply via email to